pub enum CreateTriggerError {
AlreadyExists(String),
ConcurrentModification(String),
EntityNotFound(String),
IdempotentParameterMismatch(String),
InternalService(String),
InvalidInput(String),
OperationTimeout(String),
ResourceNumberLimitExceeded(String),
}Expand description
Errors returned by CreateTrigger
Variants
AlreadyExists(String)
A resource to be created or added already exists.
ConcurrentModification(String)
Two processes are trying to modify a resource simultaneously.
EntityNotFound(String)
A specified entity does not exist
IdempotentParameterMismatch(String)
The same unique identifier was associated with two different records.
InternalService(String)
An internal service error occurred.
InvalidInput(String)
The input provided was not valid.
OperationTimeout(String)
The operation timed out.
ResourceNumberLimitExceeded(String)
A resource numerical limit was exceeded.
Implementations
Sourceimpl CreateTriggerError
impl CreateTriggerError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateTriggerError>